==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDetailDescription } from "./WebActiveNodeChangeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDetailDescriptionMetadata.c(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Row", "Number:double");
            a.item("Column", "Number:double");
            a.item("Level", "Number:double");
            a.item("Tag", "ExportedType:string:GridKeydownTargetType");
            a.item("Tag@stringUnion", "WebComponents;React");
            a.item("Tag@names", "DataCell;SummaryCell;GroupRow;HierarchicalRow;HeaderCell;MasterDetailRow");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebActiveNodeChangeEventArgsDetail", () => new WebActiveNodeChangeEventArgsDetailDescription());
            a.ac("WebActiveNodeChangeEventArgsDetail", WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDetailDescriptionMetadata, 'WebActiveNodeChangeEventArgsDetailDescriptionMetadata');
    WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDetailDescription } from "./WebActiveNodeChangeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDetailDescriptionMetadata.c(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Row", "Number:double");
            a.item("Column", "Number:double");
            a.item("Level", "Number:double");
            a.item("Tag", "ExportedType:string:GridKeydownTargetType");
            a.item("Tag@stringUnion", "WebComponents;React");
            a.item("Tag@names", "DataCell;SummaryCell;GroupRow;HierarchicalRow;HeaderCell;MasterDetailRow");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebActiveNodeChangeEventArgsDetail", () => new WebActiveNodeChangeEventArgsDetailDescription());
            a.ad("WebActiveNodeChangeEventArgsDetail", WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDetailDescriptionMetadata, 'WebActiveNodeChangeEventArgsDetailDescriptionMetadata');
    WebActiveNodeChangeEventArgsDetailDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDetailDescriptionMetadata;
})();
